==> modules_refdynawebv2_20210316080641.zip: refdynawebv2/views/ref/_form.php <==
<?php

use yii\helpers\Html;
use yii\widgets\ActiveForm;

/* @var $this yii\web\View */
/* @var $model backend\models\Ref */
/* @var $form yii\widgets\ActiveForm */
$this->registerJs(
<<<JS
    $('#parenttick').click(function(){
        if($(this).is(':checked')){
            $('#ref-param1').prop('disabled',false);
        }else{
            $('#ref-param1').prop('disabled',true);
        }
    });
JS
);
?>
<div class="banci-image-slider-form">
    <div class="wrapper wrapper-content animated fadeInRight">
        <div class="ibox float-e-margins">
                <div class="ibox-content">
                    <div class="banci-statistic-form">
                    <?php $form = ActiveForm::begin(); ?>

                    <?= $form->field($model, 'cat')->textInput(['maxlength' => true]) ?>

                    <?= $form->field($model, 'code')->textInput(['maxlength' => true]) ?>

                    <?= $form->field($model, 'descr')->textInput(['maxlength' => true]) ?>

                    <?= $form->field($model, 'param1')->dropdownList($model->parent(),['maxlength' => true,'prompt'=>'Parent..','disabled'=>'disabled'])->label('<input id="parenttick" type="checkbox" style="vertical-align:-2px"> Kategori ini mempunyai parent ?') ?>

                    <div class="form-group">
                        <?= Html::submitButton(Yii::t('app', 'Simpan'), ['class' => 'btn btn-success']) ?>
                    </div>

                     <?php ActiveForm::end(); ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

==> modules_refdynawebv2_20210707111401.zip: refdynawebv2/views/ref/_form.php <==
<?php

use yii\helpers\Html;
use yii\widgets\ActiveForm;

/* @var $this yii\web\View */
/* @var $model backend\models\Ref */
/* @var $form yii\widgets\ActiveForm */
$this->registerJs(
        <<<JS
    $('#parenttick').click(function(){
        if($(this).is(':checked')){
            $('#ref-param1').prop('disabled',false);
        }else{
            $('#ref-param1').prop('disabled',true);
        }
    });
JS
);
?>
<div class="banci-image-slider-form">
    <div class="wrapper wrapper-content animated fadeInRight">
        <div class="ibox float-e-margins">
            <div class="ibox-content">
                <div class="banci-statistic-form">
                    <?php $form = ActiveForm::begin(); ?>

                    <?= $form->field($model, 'cat')->textInput(['maxlength' => true]) ?>

                    <?= $form->field($model, 'code')->textInput(['maxlength' => true]) ?>

                    <?= $form->field($model, 'descr')->textInput(['maxlength' => true]) ?>

                    <?= $form->field($model, 'descr_en')->textInput(['maxlength' => true]) ?>

                    <?= $form->field($model, 'param1')->dropdownList($model->parent(), ['maxlength' => true, 'prompt' => 'Parent..', 'disabled' => 'disabled'])->label('<input id="parenttick" type="checkbox" style="vertical-align:-2px"> Parent Parameter') ?>

                    <div class="form-group">
                        <?= Html::submitButton(Yii::t('app', 'Save'), ['class' => 'btn btn-success']) ?>
                    </div>

                    <?php ActiveForm::end(); ?>
                </div>
            </div>
        </div>
    </div>
</div>
</div>
